@@ -14,6 +14,7 @@
 #include "kmreaderwin.h" //for inline actions
 
 #include <MailCommon/FolderTreeWidget>
+#include <MessageViewer/MDNWarningWidget>
 
 #include "messageactions.h"
 #include <Akonadi/StandardMailActionManager>
@@ -514,6 +515,7 @@ private Q_SLOTS:
     void slotReplyMessageTo(const KMime::Message::Ptr &message, bool replyToAll);
 
 private:
+    void slotSendMdnResponse(MessageViewer::MDNWarningWidget::ResponseType type);
     void slotSetFocusToViewer();
     void deleteSelectedMessages(bool confirmDelete); // completely delete message
     bool showSearchDialog();
@@ -533,6 +535,10 @@ private:
     void redoSwitchFolder();
     void undoSwitchFolder();
     void updateMoveAllToTrash();
+    void slotShowMdnInfo(const QPair<QString, bool> &mdnInfo);
+    void sendMdnInfo(const Akonadi::Item &item);
+    void slotClearFolder();
+    void slotClearCacheDone();
 
     // Message actions
     QAction *mDeleteAction = nullptr;
@@ -657,5 +663,5 @@ private:
 #endif
     KMailPluginCheckBeforeDeletingManagerInterface *mPluginCheckBeforeDeletingManagerInterface = nullptr;
     CollectionSwitcherTreeViewManager *const mCollectionSwitcherTreeViewManager;
+    QAction *mClearFolderCacheAction = nullptr;
 };
-
